@@ -4,7 +4,7 @@ use warnings;
 
 package App::Benchmark::Accessors;
 BEGIN {
-  $App::Benchmark::Accessors::VERSION = '1.102310';
+  $App::Benchmark::Accessors::VERSION = '1.102630';
 }
 # ABSTRACT: Benchmark accessor generators
 
@@ -12,7 +12,7 @@ BEGIN {
 package    # hide from PAUSE
   WithMoose;
 BEGIN {
-  $WithMoose::VERSION = '1.102310';
+  $WithMoose::VERSION = '1.102630';
 }
 use Moose;
 has myattr => ( is => 'rw' );
@@ -20,7 +20,7 @@ has myattr => ( is => 'rw' );
 package    # hide from PAUSE
   WithMooseImmutable;
 BEGIN {
-  $WithMooseImmutable::VERSION = '1.102310';
+  $WithMooseImmutable::VERSION = '1.102630';
 }
 use Moose;
 has myattr => ( is => 'rw' );
@@ -29,7 +29,7 @@ __PACKAGE__->meta->make_immutable;
 package    # hide from PAUSE
   WithMouse;
 BEGIN {
-  $WithMouse::VERSION = '1.102310';
+  $WithMouse::VERSION = '1.102630';
 }
 use Mouse;
 has myattr => ( is => 'rw' );
@@ -37,7 +37,7 @@ has myattr => ( is => 'rw' );
 package    # hide from PAUSE
   WithMouseImmutable;
 BEGIN {
-  $WithMouseImmutable::VERSION = '1.102310';
+  $WithMouseImmutable::VERSION = '1.102630';
 }
 use Mouse;
 has myattr => ( is => 'rw' );
@@ -46,7 +46,7 @@ __PACKAGE__->meta->make_immutable;
 package    # hide from PAUSE
   WithClassAccessor;
 BEGIN {
-  $WithClassAccessor::VERSION = '1.102310';
+  $WithClassAccessor::VERSION = '1.102630';
 }
 use parent qw(Class::Accessor);
 __PACKAGE__->mk_accessors(qw/myattr/);
@@ -54,7 +54,7 @@ __PACKAGE__->mk_accessors(qw/myattr/);
 package    # hide from PAUSE
   WithClassAccessorFast;
 BEGIN {
-  $WithClassAccessorFast::VERSION = '1.102310';
+  $WithClassAccessorFast::VERSION = '1.102630';
 }
 use parent qw(Class::Accessor::Fast);
 __PACKAGE__->mk_accessors(qw/myattr/);
@@ -62,15 +62,23 @@ __PACKAGE__->mk_accessors(qw/myattr/);
 package    # hide from PAUSE
   WithClassAccessorFastXS;
 BEGIN {
-  $WithClassAccessorFastXS::VERSION = '1.102310';
+  $WithClassAccessorFastXS::VERSION = '1.102630';
 }
 use parent qw(Class::Accessor::Fast::XS);
 __PACKAGE__->mk_accessors(qw/myattr/);
 
+package    # hide from PAUSE
+  WithClassXSAccessorCompat;
+BEGIN {
+  $WithClassXSAccessorCompat::VERSION = '1.102630';
+}
+use parent qw(Class::XSAccessor::Compat);
+__PACKAGE__->mk_accessors(qw/myattr/);
+
 package    # hide from PAUSE
   WithClassAccessorComplex;
 BEGIN {
-  $WithClassAccessorComplex::VERSION = '1.102310';
+  $WithClassAccessorComplex::VERSION = '1.102630';
 }
 use parent qw(Class::Accessor::Complex);
 __PACKAGE__->mk_new->mk_scalar_accessors(qw/myattr/);
@@ -78,7 +86,7 @@ __PACKAGE__->mk_new->mk_scalar_accessors(qw/myattr/);
 package    # hide from PAUSE
   WithClassAccessorConstructor;
 BEGIN {
-  $WithClassAccessorConstructor::VERSION = '1.102310';
+  $WithClassAccessorConstructor::VERSION = '1.102630';
 }
 use parent qw(Class::Accessor::Constructor Class::Accessor::Complex);
 __PACKAGE__->mk_constructor->mk_scalar_accessors(qw/myattr/);
@@ -86,7 +94,7 @@ __PACKAGE__->mk_constructor->mk_scalar_accessors(qw/myattr/);
 package    # hide from PAUSE
   WithClassAccessorClassy;
 BEGIN {
-  $WithClassAccessorClassy::VERSION = '1.102310';
+  $WithClassAccessorClassy::VERSION = '1.102630';
 }
 use Class::Accessor::Classy;
 with 'new';
@@ -96,7 +104,7 @@ no  Class::Accessor::Classy;
 package    # hide from PAUSE
   WithMojo;
 BEGIN {
-  $WithMojo::VERSION = '1.102310';
+  $WithMojo::VERSION = '1.102630';
 }
 use parent qw(Mojo::Base);
 __PACKAGE__->attr('myattr');
@@ -104,7 +112,7 @@ __PACKAGE__->attr('myattr');
 package    # hide from PAUSE
   WithClassMethodMaker;
 BEGIN {
-  $WithClassMethodMaker::VERSION = '1.102310';
+  $WithClassMethodMaker::VERSION = '1.102630';
 }
 use Class::MethodMaker
     [ scalar => [ qw/myattr/ ],
@@ -114,14 +122,14 @@ use Class::MethodMaker
 package    # hide from PAUSE
   WithObjectTiny;
 BEGIN {
-  $WithObjectTiny::VERSION = '1.102310';
+  $WithObjectTiny::VERSION = '1.102630';
 }
 use Object::Tiny qw/myattr/;
 
 package    # hide from PAUSE
   WithSpiffy;
 BEGIN {
-  $WithSpiffy::VERSION = '1.102310';
+  $WithSpiffy::VERSION = '1.102630';
 }
 use Spiffy -base;
 field 'myattr';
@@ -129,7 +137,7 @@ field 'myattr';
 package    # hide from PAUSE
   WithClassSpiffy;
 BEGIN {
-  $WithClassSpiffy::VERSION = '1.102310';
+  $WithClassSpiffy::VERSION = '1.102630';
 }
 use Class::Spiffy -base;
 field 'myattr';
@@ -137,7 +145,7 @@ field 'myattr';
 package    # hide from PAUSE
   WithAccessors;
 BEGIN {
-  $WithAccessors::VERSION = '1.102310';
+  $WithAccessors::VERSION = '1.102630';
 }
 use accessors qw(myattr);
 sub new { bless {}, shift }
@@ -145,7 +153,7 @@ sub new { bless {}, shift }
 package    # hide from PAUSE
   WithClassXSAccessor;
 BEGIN {
-  $WithClassXSAccessor::VERSION = '1.102310';
+  $WithClassXSAccessor::VERSION = '1.102630';
 }
 use Class::XSAccessor accessors => { myattr => 'myattr' };
 sub new {
@@ -156,7 +164,7 @@ sub new {
 package    # hide from PAUSE
   WithClassXSAccessorArray;
 BEGIN {
-  $WithClassXSAccessorArray::VERSION = '1.102310';
+  $WithClassXSAccessorArray::VERSION = '1.102630';
 }
 use Class::XSAccessor::Array accessors => { myattr => 0 };
 sub new {
@@ -168,7 +176,7 @@ sub new {
 package    # hide from PAUSE
   WithObjectTinyXS;
 BEGIN {
-  $WithObjectTinyXS::VERSION = '1.102310';
+  $WithObjectTinyXS::VERSION = '1.102630';
 }
 use Object::Tiny qw/myattr/;
 use Class::XSAccessor accessors => { myattr => 'myattr' }, replace => 1;
@@ -176,7 +184,7 @@ use Class::XSAccessor accessors => { myattr => 'myattr' }, replace => 1;
 package    # hide from PAUSE
   WithRose;
 BEGIN {
-  $WithRose::VERSION = '1.102310';
+  $WithRose::VERSION = '1.102630';
 }
 use parent qw(Rose::Object);
 use Rose::Object::MakeMethods::Generic(scalar => 'myattr');
@@ -190,7 +198,7 @@ use Rose::Object::MakeMethods::Generic(scalar => 'myattr');
 package    # hide from PAUSE
   WithRubyishAttribute;
 BEGIN {
-  $WithRubyishAttribute::VERSION = '1.102310';
+  $WithRubyishAttribute::VERSION = '1.102630';
 }
 use Rubyish::Attribute;
 sub new { bless {}, shift }
@@ -203,9 +211,13 @@ attr_accessor "myattr";
 __END__
 =pod
 
+=head1 NAME
+
+App::Benchmark::Accessors - Benchmark accessor generators
+
 =head1 VERSION
 
-version 1.102310
+version 1.102630
 
 =head1 DESCRIPTION
 
@@ -224,6 +236,8 @@ following generators are being benchmarked:
 
 =item Class::Accessor::Fast::XS
 
+=item Class::XSAccessor::Compat
+
 =item Class::Accessor::Complex
 
 =item Class::Accessor::Constructor
@@ -281,13 +295,12 @@ L<http://rt.cpan.org>.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see
-L<http://search.cpan.org/dist/App-Benchmark-Accessors/>.
+site near you, or see L<http://search.cpan.org/dist/App-Benchmark-Accessors/>.
 
-The development version lives at
-L<http://github.com/hanekomu/App-Benchmark-Accessors/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
+The development version lives at L<http://github.com/hanekomu/App-Benchmark-Accessors>
+and may be cloned from L<git://github.com/hanekomu/App-Benchmark-Accessors>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
 
 =head1 AUTHOR
 
